# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['filename_manager', 'tests']

package_data = \
{'': ['*']}

extras_require = \
{'dev': ['tox>=3.20.1,<4.0.0',
         'virtualenv>=20.2.2,<21.0.0',
         'pip>=20.3.1,<21.0.0',
         'twine>=3.3.0,<4.0.0',
         'pre-commit>=2.12.0,<3.0.0',
         'toml>=0.10.2,<0.11.0',
         'bump2version>=1.0.1,<2.0.0'],
 'doc': ['mkdocs>=1.1.2,<2.0.0',
         'mkdocs-include-markdown-plugin>=1.0.0,<2.0.0',
         'mkdocs-material>=6.1.7,<7.0.0',
         'mkdocstrings>=0.15.2,<0.16.0',
         'mkdocs-autorefs>=0.2.1,<0.3.0'],
 'test': ['black>=22.6,<23.0',
          'isort>=5.8.0,<6.0.0',
          'flake8>=3.9.2,<4.0.0',
          'flake8-docstrings>=1.6.0,<2.0.0',
          'mypy>=0.900,<0.901',
          'pytest>=6.2.4,<7.0.0',
          'pytest-cov>=2.12.0,<3.0.0']}

setup_kwargs = {
    'name': 'filenamemanager',
    'version': '0.1.0',
    'description': 'A simple library to handle filenames automatically for artifacts..',
    'long_description': '# Filename-Manager\n\n\n[![pypi](https://img.shields.io/pypi/v/FilenameManager.svg)](https://pypi.org/project/FilenameManager/)\n[![python](https://img.shields.io/pypi/pyversions/FilenameManager.svg)](https://pypi.org/project/FilenameManager/)\n[![Build Status](https://github.com/cemde/FilenameManager/actions/workflows/dev.yml/badge.svg)](https://github.com/cemde/FilenameManager/actions/workflows/dev.yml)\n[![codecov](https://codecov.io/gh/cemde/FilenameManager/branch/main/graphs/badge.svg)](https://codecov.io/github/cemde/FilenameManager)\n\n\n\nA simple Python library to handle filenames automatically for artifacts.\n\n\n[//]: <> (* Documentation: <https://cemde.github.io/FilenameManager>)\n* GitHub: <https://github.com/cemde/FilenameManager>\n* PyPI: <https://pypi.org/project/FilenameManager/>\n\n\n## Features\n\nThis library helps to convert a set of parameters into filenames and vice versa.\n\nWhen running a script depending on parameters `par1` (str) and `par2` (float), you might want to save artifacts with a filename generated by these parameters.\n\nYou can decide how to format each parameter in the saved filename, e.g. `fp4.4` will padd the float with leading `0`s and with 4 digits. For example, `1.2` will be `0001.2000`.\n\n### Save artifacts\n```python\nfrom filename_manager import FilenameManager\n\nfm = FilenameManager({"par1": "str", "par2": "fp.4.4}"}, prefix="subfolder/prefix", postfix=".csv")\n\n# define your parameters\npar1 = "Hello"\npar2 = "3.11"\n\n# super fancy script\nresults = "placeholder"\n\n# create filename\nfilename=fm.encode(par1=par1, par2=par2)\n\n# save\n...\n\n```\n\nthe filename will be `subfolder/prefix_par1_Hello_par2_0003.1100.csv`.\n\n### Load artifacts\n\n```python\nfrom filename_manager import FilenameManager\n\nfm = FilenameManager({"par1": "str", "par2": "fp.4.4}"}, prefix="subfolder/prefix", postfix=".csv")\n\n# get your filename\nfilename = "subfolder/prefix_par1_Hello_par2_0003.1100.csv"\n\n# parse filename\npars = fm.decode(filename)\n```\n\nThe variable `pars` is a dictionary with `{"par1": "Hello", "par2": 3.11}`.\n\n\n## Documentation\n\nThe documentation is given in the docstrings. Only two classes exist. `Parameter` and `FilenameManager`.\n\nThe supported formats are\n\n- `fp*.*` for floating point parameters. E.g. "fp4.3" formats 1.2 as "0001.200"\n- `str` for string parameters.\n- `str*` for string parameters with * characters padded with 0 in the end.\n- `*str` for string parameters with * characters padded with 0 in the beginning.\n- `bool` for boolean parameters.\n- `*int` for integer parameters with * leading zeros.\n\n## Credits\n\nThis package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.\n',
    'author': 'Cornelius Emde',
    'author_email': 'c.emde@me.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/cemde/FilenameManager',
    'packages': packages,
    'package_data': package_data,
    'extras_require': extras_require,
    'python_requires': '>=3.6.2,<4.0',
}


setup(**setup_kwargs)
